ledger.LedgerInfo (ledger info) — amici1

# `ledger.LedgerInfo` (ledger info)

LedgerInfo(user, entry_date)

Master tables : ledger.LedgerInfoTable (ledger infos)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- User (user) : OneToOneField pointing to the user.

- Last entry date (entry_date) : The last value this user typed as entry_date of a voucher. It is the default value for every new voucher.

- Name (name_column) : See `lino_xl.lib.ledger.models.LedgerInfo.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.ledger.models.LedgerInfo.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.ledger.models.LedgerInfo.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
user | User | OneToOneField pointing to the user.
entry_date | Last entry date | The last value this user typed as entry_date of a voucher. It is the default value for every new voucher.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |